#[repr(u8)]pub enum Ps {
NO_OVERRIDE = 0,
_RESERVED_1 = 1,
PRI_DET_OVERRIDE = 2,
_RESERVED_3 = 3,
}Variants
NO_OVERRIDE = 0
No overrides. Bit field must remain at this value during normal USB data communication to prevent unexpected conditions on USB_DP and USB_DM pins. (Default)
_RESERVED_1 = 1
PRI_DET_OVERRIDE = 2
Enables VDP_SRC voltage source for the USB_DP pin and IDM_SINK current source for the USB_DM pin.
_RESERVED_3 = 3
Implementations